{**
	CESYS Software License - Version 1.0 - January 1st, 2016

	Permission is hereby granted, free of charge, to any person or organization
	obtaining a copy of the software and accompanying documentation covered by
	this license (the "Software") to use, reproduce, display, distribute,
	execute, and transmit the Software, and to prepare derivative works of the
	Software, and to permit third-parties to whom the Software is furnished to
	do so, all subject to the following:

	The software must only be used to operate hardware manufactured by 
	CESYS GmbH, Herzogenaurach.

	The copyright notices in the Software and this entire statement, including
	the above license grant, this restriction and the following disclaimer,
	must be included in all copies of the Software, in whole or in part, and
	all derivative works of the Software, unless such copies or derivative
	works are solely in the form of machine-executable object code generated by
	a source language processor.

	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
	IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
	FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
	SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
	FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
	ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
	DEALINGS IN THE SOFTWARE.
  
	CeboMsr - Delphi example - Counter.

	This example shows how to use a counter. Digital I/O #1 is wired
	to the counter, so every time this I/O is pulsed, the counter will
	react on this event.

	Requirements: IO-1 must be connected to CNT (IO-0 on Cebo Stick).

	@author Daniel Schroll
}
program CounterExample;
	uses
		SysUtils,
		CeboMsr in 'cebomsr\CeboMsr.pas';

procedure CounterTest(Device: TDevice);
		var
			Dp0: TDigitalPort;
			Cnt: TCounter;
			I: longint;
	begin

		// Create local copies, this shortens the source.
		Dp0 := Device.DigitalPorts[0];
		Cnt := Device.Counters[0];

		// Set IO-1 as output.
		Dp0.OutputEnableMask := $02;

		// Enable the counter
		Cnt.Enabled := true;

		// Check the counters current value.
		writeln('Counter before starting: ' + IntToStr(Cnt.Value));

		// Pulse IO-1 3 times.
		for I := 0 to 2 do begin
			Dp0.Value := $02;
			Dp0.Value := $00;
		end;

		// Check the counters current value.
		writeln('Counter should be 3: ' + IntToStr(Cnt.Value));

		// Reset and ...
		Cnt.Reset();

		// ... disabel the counter.
		Cnt.Enabled := false;

		// Check the counters current value.
		writeln('Counter should be 0: ' + inttostr(Cnt.Value));

		// Pulse IO-1 3 times, the counter should ignore these pulses.
		for I := 0 to 2 do begin
			Dp0.Value := $02;
			Dp0.Value := $00;
		end;

		// Check the counters current value.
		writeln('Counter should still be 0: ' + inttostr(Cnt.Value));
	end;

var
	Devices: TDeviceList;
	Device: TDevice;

begin
	try
		// Search for devices
		Devices := CeboMsr.TLibraryInterface.Enumerate(CeboMsr.DeviceType.AllDevices);

		// If at least one device has been found, use the first one
		if (length(Devices) > 0) then begin
			Device := Devices[0];

			// Open device, nothing can be done without doing this
			Device.Open();

			// *** DIGITAL PORTS AND ANALOG OUTPUTS ARE MODIFIED DURING THIS ***
			// *** SECTION, SO DO NOT CONNECT ANY PERIPHERALS WITHOUT STUDYING ***
			// *** THE ACTIONS DONE HERE, OTHERWISE YOUR PERIPHERALS MAY BE DAMAGED !!! ***
			CounterTest(Device);

			// Finalize device usage, this free's up the device, so it can be used
			// again, including other applications.
			Device.Close();
		end else begin
			writeln('No Devices found!');
		end;
		readln;
	except
		on E: EArgumentException do begin
			writeln(E.Message);
			readln;
		end;
		on E: EIndexOutOfRangeException do begin
			writeln(E.Message);
			readln;
		end;
		on E: EInvalidOperationException do begin
			writeln(E.Message);
			readln;
		end;
		on E: EIoException do begin
			writeln(E.Message);
			readln;
		end;
	end;
end.
