/* 
  CESYS Software License - Version 1.0 - January 1st, 2016

  Permission is hereby granted, free of charge, to any person or organization
  obtaining a copy of the software and accompanying documentation covered by
  this license (the "Software") to use, reproduce, display, distribute,
  execute, and transmit the Software, and to prepare derivative works of the
  Software, and to permit third-parties to whom the Software is furnished to
  do so, all subject to the following:

  The software must only be used to operate hardware manufactured by 
  CESYS GmbH, Herzogenaurach.

  The copyright notices in the Software and this entire statement, including
  the above license grant, this restriction and the following disclaimer,
  must be included in all copies of the Software, in whole or in part, and
  all derivative works of the Software, unless such copies or derivative
  works are solely in the form of machine-executable object code generated by
  a source language processor.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
  SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
  FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  DEALINGS IN THE SOFTWARE.
  
  Written by Thomas Hoppe <thomas.hoppe@cesys.com>, 2016
*/  

package com.cesys.cebo.cebomsr;

/**
 * These objects are used to set the range of analog inputs and outputs.
 * Direct construction is not possible, getSupportedRanges() of {@link AnalogInput} and
 * {@link AnalogOutput} can be used to request the possible ranges of an input or output.
 *
 * @author Thomas Hoppe
 */
public final class Range {
	private final int _interfaceId;
	private final float _minValue, _maxValue;
	private final int _defaultInterChannelDelay;

	int getInterfaceId() {
		return _interfaceId;
	}

	int getDefaultInterChannelDelay() {
		return _defaultInterChannelDelay;
	}

	Range(int interfaceId, float minValue, float maxValue, int defaultInterChannelDelay) {
		_interfaceId = interfaceId;
		_minValue = minValue;
		_maxValue = maxValue;
		_defaultInterChannelDelay = defaultInterChannelDelay;
	}

	/**
	 * Return lower voltage.
	 */
	public float getMinValue() {
		return _minValue;
	}

	/**
	 * Return upper voltage.
	 */
	public float getMaxValue() {
		return _maxValue;
	}

	@Override
	public String toString() {
		return "Range: " + _minValue + "V - " + _maxValue + "V";
	}
}
